==> librenms-24.8.1v0.tgz: librenms/lang/pt-BR/sensors.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Linhas de Linguagem dos Sensores
    |--------------------------------------------------------------------------
    |
    | As seguintes linhas de linguagem são usadas para traduzir nomes e unidades dos sensores
    |
    */

    'title' => 'Sensores',
    'airflow' => [
        'short' => 'Fluxo de Ar',
        'long' => 'Fluxo de Ar',
        'unit' => 'cfm',
        'unit_long' => 'Pés Cúbicos por Minuto',
    ],
    'ber' => [
        'short' => 'BER',
        'long' => 'Taxa de Erro de Bit',
        'unit' => '',
        'unit_long' => '',
    ],
    'charge' => [
        'short' => 'Carga',
        'long' => 'Porcentagem de Carga',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'chromatic_dispersion' => [
        'short' => 'Dispersão Cromática',
        'long' => 'Dispersão Cromática',
        'unit' => 'ps/nm/km',
        'unit_long' => 'Picosegundos por Nanômetro por Quilômetro',
    ],
    'cooling' => [
        'short' => 'Resfriamento',
        'long' => '',
        'unit' => 'W',
        'unit_long' => 'Watts',
    ],
    'count' => [
        'short' => 'Contagem',
        'long' => 'Contagem',
        'unit' => '',
        'unit_long' => '',
    ],
    'current' => [
        'short' => 'Corrente',
        'long' => 'Corrente',
        'unit' => 'A',
        'unit_long' => 'Ampéres',
    ],
    'dbm' => [
        'short' => 'dBm',
        'long' => 'dBm',
        'unit' => 'dBm',
        'unit_long' => 'Decibéis-Miliwatt',
    ],
    'delay' => [
        'short' => 'Atraso',
        'long' => 'Atraso',
        'unit' => 's',
        'unit_long' => 'Segundos',
    ],
    'eer' => [
        'short' => 'EER',
        'long' => 'Razão de Eficiência Energética',
        'unit' => '',
        'unit_long' => '',
    ],
    'fanspeed' => [
        'short' => 'Velocidade do Ventilador',
        'long' => 'Velocidade do Ventilador',
        'unit' => 'RPM',
        'unit_long' => 'Rotações por Minuto',
    ],
    'frequency' => [
        'short' => 'Frequência',
        'long' => 'Frequência',
        'unit' => 'Hz',
        'unit_long' => 'Hertz',
    ],
    'humidity' => [
        'short' => 'Umidade',
        'long' => 'Porcentagem de Umidade',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'load' => [
        'short' => 'Carga',
        'long' => 'Porcentagem de Carga',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'loss' => [
        'short' => 'Perda',
        'long' => 'Porcentagem de Perda',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'power' => [
        'short' => 'Potência',
        'long' => 'Potência',
        'unit' => 'W',
        'unit_long' => 'Watts',
    ],
    'power_consumed' => [
        'short' => 'Potência Consumida',
        'long' => 'Potência Consumida',
        'unit' => 'kWh',
        'unit_long' => 'Quilowatts-Hora',
    ],
    'power_factor' => [
        'short' => 'Fator de Potência',
        'long' => 'Fator de Potência',
        'unit' => '',
        'unit_long' => '',
    ],
    'pressure' => [
        'short' => 'Pressão',
        'long' => 'Pressão',
        'unit' => 'kPa',
        'unit_long' => 'Quilopascais',
    ],
    'quality_factor' => [
        'short' => 'Fator de Qualidade',
        'long' => 'Fator de Qualidade',
        'unit' => '',
        'unit_long' => '',
    ],
    'runtime' => [
        'short' => 'Tempo de Execução',
        'long' => 'Tempo de Execução',
        'unit' => 'Min',
        'unit_long' => 'Minutos',
    ],
    'signal' => [
        'short' => 'Sinal',
        'long' => 'Sinal',
        'unit' => 'dBm',
        'unit_long' => 'Decibéis-Miliwatt',
    ],
    'tv_signal' => [
        'short' => 'Sinal',
        'long' => 'Sinal de TV',
        'unit' => 'dBmV',
        'unit_long' => 'Decibéis-Milivolt',
    ],
    'bitrate' => [
        'short' => 'Taxa de Bits',
        'long' => 'Taxa de Bits',
        'unit' => 'bps',
        'unit_long' => 'Bits por Segundo',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => 'Relação Sinal-Ruído',
        'unit' => 'dB',
        'unit_long' => 'Decibéis',
    ],
    'state' => [
        'short' => 'Estado',
        'long' => 'Estado',
        'unit' => '',
    ],
    'temperature' => [
        'short' => 'Temperatura',
        'long' => 'Temperatura',
        'unit' => '°C',
        'unit_long' => '° Celsius',
    ],
    'voltage' => [
        'short' => 'Tensão',
        'long' => 'Tensão',
        'unit' => 'V',
        'unit_long' => 'Volts',
    ],
    'waterflow' => [
        'short' => 'Fluxo de Água',
        'long' => 'Fluxo de Água',
        'unit' => 'l/m',
        'unit_long' => 'Litros por Minuto',
    ],
    'percent' => [
        'short' => 'Porcentagem',
        'long' => 'Porcentagem',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
];

==> librenms-24.11.0v0.tgz: librenms/lang/pt-BR/sensors.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Linhas de Linguagem dos Sensores
    |--------------------------------------------------------------------------
    |
    | As seguintes linhas de linguagem são usadas para traduzir nomes e unidades dos sensores
    |
    */

    'title' => 'Sensores',
    'airflow' => [
        'short' => 'Fluxo de Ar',
        'long' => 'Fluxo de Ar',
        'unit' => 'cfm',
        'unit_long' => 'Pés Cúbicos por Minuto',
    ],
    'ber' => [
        'short' => 'BER',
        'long' => 'Taxa de Erro de Bit',
        'unit' => '',
        'unit_long' => '',
    ],
    'charge' => [
        'short' => 'Carga',
        'long' => 'Porcentagem de Carga',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'chromatic_dispersion' => [
        'short' => 'Dispersão Cromática',
        'long' => 'Dispersão Cromática',
        'unit' => 'ps/nm',
        'unit_long' => 'Picosegundos por Nanômetro',
    ],
    'cooling' => [
        'short' => 'Resfriamento',
        'long' => '',
        'unit' => 'W',
        'unit_long' => 'Watts',
    ],
    'count' => [
        'short' => 'Contagem',
        'long' => 'Contagem',
        'unit' => '',
        'unit_long' => '',
    ],
    'current' => [
        'short' => 'Corrente',
        'long' => 'Corrente',
        'unit' => 'A',
        'unit_long' => 'Ampéres',
    ],
    'dbm' => [
        'short' => 'dBm',
        'long' => 'dBm',
        'unit' => 'dBm',
        'unit_long' => 'Decibéis-Miliwatt',
    ],
    'delay' => [
        'short' => 'Atraso',
        'long' => 'Atraso',
        'unit' => 's',
        'unit_long' => 'Segundos',
    ],
    'eer' => [
        'short' => 'EER',
        'long' => 'Razão de Eficiência Energética',
        'unit' => '',
        'unit_long' => '',
    ],
    'fanspeed' => [
        'short' => 'Velocidade do Ventilador',
        'long' => 'Velocidade do Ventilador',
        'unit' => 'RPM',
        'unit_long' => 'Rotações por Minuto',
    ],
    'frequency' => [
        'short' => 'Frequência',
        'long' => 'Frequência',
        'unit' => 'Hz',
        'unit_long' => 'Hertz',
    ],
    'humidity' => [
        'short' => 'Umidade',
        'long' => 'Porcentagem de Umidade',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'load' => [
        'short' => 'Carga',
        'long' => 'Porcentagem de Carga',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'loss' => [
        'short' => 'Perda',
        'long' => 'Porcentagem de Perda',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
    'power' => [
        'short' => 'Potência',
        'long' => 'Potência',
        'unit' => 'W',
        'unit_long' => 'Watts',
    ],
    'power_consumed' => [
        'short' => 'Potência Consumida',
        'long' => 'Potência Consumida',
        'unit' => 'kWh',
        'unit_long' => 'Quilowatts-Hora',
    ],
    'power_factor' => [
        'short' => 'Fator de Potência',
        'long' => 'Fator de Potência',
        'unit' => '',
        'unit_long' => '',
    ],
    'pressure' => [
        'short' => 'Pressão',
        'long' => 'Pressão',
        'unit' => 'kPa',
        'unit_long' => 'Quilopascais',
    ],
    'quality_factor' => [
        'short' => 'Fator de Qualidade',
        'long' => 'Fator de Qualidade',
        'unit' => '',
        'unit_long' => '',
    ],
    'runtime' => [
        'short' => 'Tempo de Execução',
        'long' => 'Tempo de Execução',
        'unit' => 'Min',
        'unit_long' => 'Minutos',
    ],
    'signal' => [
        'short' => 'Sinal',
        'long' => 'Sinal',
        'unit' => 'dBm',
        'unit_long' => 'Decibéis-Miliwatt',
    ],
    'tv_signal' => [
        'short' => 'Sinal',
        'long' => 'Sinal de TV',
        'unit' => 'dBmV',
        'unit_long' => 'Decibéis-Milivolt',
    ],
    'bitrate' => [
        'short' => 'Taxa de Bits',
        'long' => 'Taxa de Bits',
        'unit' => 'bps',
        'unit_long' => 'Bits por Segundo',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => 'Relação Sinal-Ruído',
        'unit' => 'dB',
        'unit_long' => 'Decibéis',
    ],
    'state' => [
        'short' => 'Estado',
        'long' => 'Estado',
        'unit' => '',
    ],
    'temperature' => [
        'short' => 'Temperatura',
        'long' => 'Temperatura',
        'unit' => '°C',
        'unit_long' => '° Celsius',
    ],
    'voltage' => [
        'short' => 'Tensão',
        'long' => 'Tensão',
        'unit' => 'V',
        'unit_long' => 'Volts',
    ],
    'waterflow' => [
        'short' => 'Fluxo de Água',
        'long' => 'Fluxo de Água',
        'unit' => 'l/m',
        'unit_long' => 'Litros por Minuto',
    ],
    'percent' => [
        'short' => 'Porcentagem',
        'long' => 'Porcentagem',
        'unit' => '%',
        'unit_long' => 'Porcento',
    ],
];
